@@ -3,14 +3,15 @@ Main interface for mediapackage service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.mediapackage import (
+    from mypy_boto3_mediapackage import (
         Client,
         ListChannelsPaginator,
         ListHarvestJobsPaginator,
         ListOriginEndpointsPaginator,
         MediaPackageClient,
-        )
+    )
 
     session = boto3.Session()
 
@@ -20,14 +21,17 @@ Usage::
     list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
     list_harvest_jobs_paginator: ListHarvestJobsPaginator = client.get_paginator("list_harvest_jobs")
     list_origin_endpoints_paginator: ListOriginEndpointsPaginator = client.get_paginator("list_origin_endpoints")
+    ```
 """
-from mypy_boto3_mediapackage.client import MediaPackageClient, MediaPackageClient as Client
+from mypy_boto3_mediapackage.client import MediaPackageClient
 from mypy_boto3_mediapackage.paginator import (
     ListChannelsPaginator,
     ListHarvestJobsPaginator,
     ListOriginEndpointsPaginator,
 )
 
+Client = MediaPackageClient
+
 
 __all__ = (
     "Client",
