@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for mediapackage service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.mediapackage import (
+
+    from mypy_boto3_mediapackage import MediaPackageClient
+    from mypy_boto3_mediapackage.paginator import (
         ListChannelsPaginator,
         ListHarvestJobsPaginator,
         ListOriginEndpointsPaginator,
@@ -15,10 +19,12 @@ Usage::
     list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
     list_harvest_jobs_paginator: ListHarvestJobsPaginator = client.get_paginator("list_harvest_jobs")
     list_origin_endpoints_paginator: ListOriginEndpointsPaginator = client.get_paginator("list_origin_endpoints")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_mediapackage.type_defs import (
     ListChannelsResponseTypeDef,
     ListHarvestJobsResponseTypeDef,
@@ -26,26 +32,25 @@ from mypy_boto3_mediapackage.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = ("ListChannelsPaginator", "ListHarvestJobsPaginator", "ListOriginEndpointsPaginator")
 
 
 class ListChannelsPaginator(Boto3Paginator):
     """
-    [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels)
+    [Paginator.ListChannels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.42/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListChannelsResponseTypeDef]:
         """
-        [ListChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels.paginate)
+        [ListChannels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.42/reference/services/mediapackage.html#MediaPackage.Paginator.ListChannels.paginate)
         """
 
 
 class ListHarvestJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListHarvestJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs)
+    [Paginator.ListHarvestJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.42/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs)
     """
 
     def paginate(
@@ -55,18 +60,18 @@ class ListHarvestJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListHarvestJobsResponseTypeDef]:
         """
-        [ListHarvestJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs.paginate)
+        [ListHarvestJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.42/reference/services/mediapackage.html#MediaPackage.Paginator.ListHarvestJobs.paginate)
         """
 
 
 class ListOriginEndpointsPaginator(Boto3Paginator):
     """
-    [Paginator.ListOriginEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints)
+    [Paginator.ListOriginEndpoints documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.42/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints)
     """
 
     def paginate(
         self, ChannelId: str = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListOriginEndpointsResponseTypeDef]:
         """
-        [ListOriginEndpoints.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.7/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints.paginate)
+        [ListOriginEndpoints.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.42/reference/services/mediapackage.html#MediaPackage.Paginator.ListOriginEndpoints.paginate)
         """
